==> lxqt-config-0.15.0.tar.xz: lxqt-config-0.15.0/lxqt-config-locale/translations/lxqt-config-locale_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>Orszá&amp;g:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>&amp;Részletes beállítás</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Számok:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>&amp;Idő:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Pénznem:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Mértékrendszer:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation type="unfinished">Egy&amp;bevetés és sorrend:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;Példák&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>Számok:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>Idő:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>Pénznem:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>Mértékrendszer:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="125"/>
        <source>No change</source>
        <translation>Változatlan</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="314"/>
        <source>Format Settings Changed</source>
        <translation>Formátum változott</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="315"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Menti a változtatásokat? Ez a legközelebbi bejelentkezéskor lép érvénybe.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="436"/>
        <source>Imperial UK</source>
        <translation>UK angol</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="440"/>
        <source>Imperial US</source>
        <translation>US angol</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="444"/>
        <source>Metric</source>
        <translation>Metrikus</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>LXQt területi beállítások</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>Területi beállítások</translation>
    </message>
</context>
</TS>

==> lxqt-config-1.0.0.tar.xz: lxqt-config-1.0.0/lxqt-config-locale/translations/lxqt-config-locale_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>Ré&amp;gió:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>&amp;Részletes beállítások</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Számok:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>&amp;Idő:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Pénznem:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Mértékrendszer:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation type="unfinished">Egy&amp;bevetés és sorrend:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;Példák&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>Számok:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>Idő:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>Pénznem:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>Mértékrendszer:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="127"/>
        <source>No change</source>
        <translation>Változatlan</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="316"/>
        <source>Format Settings Changed</source>
        <translation>Formátumbeállítások megváltoztak</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="317"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Menti a változtatásokat? Ez a legközelebbi bejelentkezéskor lép érvénybe.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="438"/>
        <source>Imperial UK</source>
        <translation>UK angol</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="442"/>
        <source>Imperial US</source>
        <translation>US angol</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="446"/>
        <source>Metric</source>
        <translation>Metrikus</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>LXQt területi beállítások</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>Területi beállítások</translation>
    </message>
</context>
</TS>
